@@ -8,6 +8,9 @@
 // Some static assets may be required by the custom widget javascript. The base
 // url for the notebook is not known at build time and is therefore computed
 // dynamically.
-(window as any).__webpack_public_path__ = document.querySelector('body')!.getAttribute('data-base-url') + 'nbextensions/jupyter-cytoscape';
+
+(window as any).__webpack_public_path__ =
+  document.querySelector('body')!.getAttribute('data-base-url') + // eslint-disable-line @typescript-eslint/no-non-null-assertion
+  'nbextensions/jupyter-cytoscape';
 
 export * from './index';
